function [FitResults] = DOASISfit(TargetSpec, FitScenario)
%DOASISFIT This function performs a DOAS fit using the DOASIS software
%   MeasSpec: A CSpectrum object holding the spectrum to which the fit will be applied
%   FitScenario: A CFitScenario object where BuildFitScenario has already been called (the fs is saved to the hard drive).


    % save the target spectrum:    
    MeasSpec.Save('target.std');    
    fid = fopen('dfit.js', 'wt');
    
    % import the namespaces
    fprintf(fid, 'import System; import DoasCore; import DoasCore.Spectra; import DoasCore.Math;\n');
    fprintf(fid, '\n');
    
    % create an ISpectrum to hold the target
    fprintf(fid, 'var TargetSpec : ISpectrum = Specbar.GetSpectrum("Target");\n');
    
    % open the Target spectrum
    fprintf(fid, 'TargetSpec.Open(target.std);\n');
    
    % open the fit scenario
    if isempty(FitScenario.FileName)
        disp('Error - this fit scenario has not been built!');
    else
        fprintf(fid, ['var fit = DoasFit.Open(' FitScenario.FileName ');\n']);
    end
    
    % do the fit
    fprintf(fid, 'if(fit.DoFit(MeasSpec
    
    for i = 1:length(FS.CrossSections)
        fprintf(fid, 'var CrossSectionSpec%d : ISpectrum = Specbar.GetSpectrum("%s");\n', i, FS.CrossSections{i}.Spectrum.Name);                
    end

    for i = 1:length(FS.CrossSections)
        fprintf(fid, 'CrossSectionSpec%d.Open("cs%d.std");\n', i, i);                
    end  
            

end

